@@ -1,29 +1,28 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 #include "gravatarconfiguresettingswidget.h"
+#include "gravatarsettings.h"
 #include <Gravatar/GravatarCache>
-#include <PimCommon/ConfigureImmutableWidgetUtils>
 #include <KLocalizedString>
 #include <KPluralHandlingSpinBox>
 #include <KSeparator>
+#include <PimCommon/ConfigureImmutableWidgetUtils>
 #include <QCheckBox>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
-#include <QHBoxLayout>
 #include <QVBoxLayout>
-#include "gravatarsettings.h"
 
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setObjectName(QStringLiteral("mainlayout"));
     topLayout->setContentsMargins(0, 0, 0, 0);
     mUseDefaultPixmap = new QCheckBox(i18n("Use Default Image"), this);
@@ -40,10 +39,9 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     connect(mUseLibravatar, &QCheckBox::toggled, mFallbackGravatar, &QCheckBox::setEnabled);
     mFallbackGravatar->setEnabled(false);
 
-
-    auto *cacheSizeLayout = new QHBoxLayout;
+    auto cacheSizeLayout = new QHBoxLayout;
     topLayout->addLayout(cacheSizeLayout);
-    QLabel *lab = new QLabel(i18n("Gravatar Cache Size:"), this);
+    auto lab = new QLabel(i18n("Gravatar Cache Size:"), this);
     lab->setObjectName(QStringLiteral("gravatarcachesizelabel"));
     cacheSizeLayout->addWidget(lab);
 
@@ -55,11 +53,11 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     cacheSizeLayout->addWidget(mGravatarCacheSize);
     cacheSizeLayout->addStretch();
 
-    KSeparator *separator = new KSeparator(this);
+    auto separator = new KSeparator(this);
     separator->setObjectName(QStringLiteral("separator"));
     topLayout->addWidget(separator);
 
-    auto *buttonLayout = new QHBoxLayout;
+    auto buttonLayout = new QHBoxLayout;
     topLayout->addLayout(buttonLayout);
     mClearGravatarCache = new QPushButton(i18n("Clear Gravatar Cache"), this);
     mClearGravatarCache->setObjectName(QStringLiteral("cleargravatarcachebutton"));
@@ -73,10 +71,7 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     connect(mClearGravatarCache, &QAbstractButton::clicked, this, &GravatarConfigureSettingsWidget::slotClearGravatarCache);
 }
 
-GravatarConfigureSettingsWidget::~GravatarConfigureSettingsWidget()
-{
-
-}
+GravatarConfigureSettingsWidget::~GravatarConfigureSettingsWidget() = default;
 
 void GravatarConfigureSettingsWidget::slotClearGravatarCache()
 {
